@@ -5,12 +5,13 @@
 /**
  * @file api/v1/contexts/index.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup api_v1_contexts
+ *
  * @brief Handle API requests for contexts (presses).
  */
-import('lib.pkp.api.v1.contexts.PKPContextHandler');
-return new PKPContextHandler();
+
+return new \PKP\API\v1\contexts\PKPContextHandler();
